@@ -14,13 +14,18 @@ names = {
 DATA = "/work/papers/data"
 PAPER = "/work/papers"
 
+from os.path import dirname
 
 def get_vol6_64(nums: int):
-    import sys
+    '''
+    获得一个64个序列长度的电池电压第6阶段放电数据
+    '''
+    # import sys
     # dir_path = abspath('tool.py')
     # print(sys.path[0])
     # chdir(dir_path[0])
-    real_path = join(sys.path[0],'vol6_64.py')
+    dir_name = dirname(__file__)
+    real_path = join(dir_name,'vol6_64.py')
     # abs_path = abspath('tool.py')
     # print(abs_path)
     data = load(real_path)
@@ -34,4 +39,4 @@ def get_vol6_64(nums: int):
 # print(x.shape)
 # print(x[0:1010].shape)
 
-get_vol6_64(10221)
\ No newline at end of file
+# get_vol6_64(10221)
\ No newline at end of file
